@@ -1,18 +1,4 @@
 
-.onLoad <- function(libname, pkgname) {
-    
-    patharch <- hdf5_plugin_path()
-    existing_path <- Sys.getenv("HDF5_PLUGIN_PATH")
-    
-    ## retain any existing plugin locations
-    if(nzchar(existing_path)) {
-      sep = if(.Platform$OS.type == "windows") ";" else ":"
-      patharch <- paste(patharch, existing_path, sep = sep)
-    }
-    
-    Sys.setenv(HDF5_PLUGIN_PATH=patharch)
-}
-
 #' Return location of installed filters
 #' 
 #' This function can be used to find the location of the installed filters.
@@ -39,4 +25,21 @@ hdf5_plugin_path <- function() {
     patharch <- paste0(path, arch)
     
     return(patharch)
+}
+
+#' Return a list of installed filters
+#' 
+#' This function can be used to produce a vector of the installed filters.
+#' 
+#' @return A character vector containing the names of the installed filters.
+#' @examples
+#' available_filters()
+#' 
+#' @export
+available_filters <- function() {
+  
+  path <- system.file("lib", package="rhdf5filters", mustWork=FALSE)
+  object_files <- tools::file_path_sans_ext(list.files(path))
+  filters <- sub(pattern = "libH5Z", replacement = "", x = object_files)
+  return(filters)
 }
\ No newline at end of file
